@@ -1,5 +1,5 @@
 package Password::Policy;
-$Password::Policy::VERSION = '0.03';
+$Password::Policy::VERSION = '0.04';
 # ABSTRACT: Make managing multiple password strength profiles easy
 
 use strict;
@@ -163,7 +163,7 @@ Password::Policy - Make managing multiple password strength profiles easy
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 UNICODE
 
@@ -298,7 +298,7 @@ to encrypt, and optionally any arguments you want to pass to the algorithm's mod
 
 =head1 ACKNOWLEDGEMENTS
 
-The unit tests got a nice round of cleanup from StarlightPL. Thanks!
+The unit tests got a nice round of cleanup from StarLightPL. Thanks!
 
 =head1 AUTHOR
 
